@@ -23,9 +23,9 @@
 
 #include "gda-firebird-recordset.h"
 #include "gda-firebird-provider.h"
-#include "libgda/gda-quark-list.h"
+#include "gda-firebird-blob.h"
+#include <libgda/gda-quark-list.h>
 #include <libgda/gda-intl.h>
-
 #include <glib/gprintf.h>
 #include <string.h>
 #include <math.h>
@@ -262,7 +262,9 @@ fb_sql_get_statement_type (GdaFirebirdConnection *fcnc,
 			   GdaFirebirdRecordset *recset)
 {
 	int length;
-	char type_item[] = { isc_info_sql_stmt_type };
+	char type_item[] = { 
+		isc_info_sql_stmt_type
+	};
 	char buffer[8];
                                                                                                                             
 	g_return_val_if_fail (GDA_IS_FIREBIRD_RECORDSET (recset), -1);
@@ -281,43 +283,6 @@ fb_sql_get_statement_type (GdaFirebirdConnection *fcnc,
 }
 
 
-/*
- *
- *  fb_sql_affected_rows
- *
- *  Gets SELECT statement affected rows
- *
- *  Returns: Number of affected rows, or 0 if failed
- */
-static gint
-fb_sql_affected_rows (GdaFirebirdConnection *fcnc,
-		      GdaFirebirdRecordset *recset)
-{
-	/* FIXME: This code should work but for some reason allways returns 0 affected rows    */
-	/* This code should work for non SELECT statements like UPDATE, DELETE and other alike */
-	gchar buffer[33], *p_buffer, item;
-	gint length, res_val;
-	gchar type_item[] = { isc_info_sql_records };
-
-	g_return_val_if_fail (GDA_IS_FIREBIRD_RECORDSET (recset), 0);
-
-	if (! isc_dsql_sql_info (fcnc->status, &(recset->priv->sql_handle), sizeof(type_item), type_item, 
-			       sizeof(buffer), buffer)) {
-		for (p_buffer = buffer; *p_buffer != isc_info_end; ) {
-			item = *p_buffer++;
-			length = isc_vax_integer (p_buffer, 2);
-			p_buffer += 2;
-			res_val = isc_vax_integer (p_buffer, length);
-			p_buffer += length;
-			if (item == isc_info_req_select_count)
-				return res_val;
-		}
-	}
-		
-	return 0;
-}
-
-
 /*
  *  fb_sql_prepare
  *
@@ -412,7 +377,8 @@ fb_sql_unprepare (GdaFirebirdConnection *fcnc,
 		fb_sql_result_free (recset->priv->sql_result);
 
 		/* Free cursors */
-		isc_dsql_free_statement (fcnc->status, &(recset->priv->sql_handle), DSQL_drop);
+		if (recset->priv->sql_handle)
+			isc_dsql_free_statement (fcnc->status, &(recset->priv->sql_handle), DSQL_drop);
 		
 		return TRUE;
 	}
@@ -466,6 +432,7 @@ fb_gda_value_fill (GdaValue *gda_value,
 	GdaTime a_time;
 	GdaDate a_date;
 	GdaTimestamp a_times;
+	GdaBlob *blob = NULL;
 	struct tm *a_date_time;
 	gpointer tmp_big, field_data;
 	struct vary *var_text;
@@ -475,7 +442,7 @@ fb_gda_value_fill (GdaValue *gda_value,
 	g_return_if_fail (GDA_IS_FIREBIRD_RECORDSET (recset));
 
 	sql_result = recset->priv->sql_result;
-	(gchar *) field_data = sql_result->sqlvar[field_number].sqldata;
+	field_data = (gchar *) sql_result->sqlvar[field_number].sqldata;
 	
 	/* If value is null  */
 	if (*(sql_result->sqlvar[field_number].sqlind) == -1) {
@@ -486,19 +453,21 @@ fb_gda_value_fill (GdaValue *gda_value,
 	switch (field_type) {
 		case SQL_ARRAY:
 		case SQL_ARRAY+1:
-			g_print (_("Firebird's ARRAY datatype not supported yet !\n"));
+			g_print (_("Firebird's ARRAY datatype not supported yet!\n"));
 			gda_value_set_null (gda_value);		
 			break;
 		case SQL_BLOB:
 		case SQL_BLOB+1:
-			g_print (_("Firebird's BLOB datatype not supported yet !\n"));
-			gda_value_set_null (gda_value);		
+			blob = gda_firebird_blob_new (recset->priv->cnc);
+			gda_firebird_blob_set_id (blob, (const ISC_QUAD *) field_data);
+			gda_value_set_blob (gda_value, (const GdaBlob *) blob);
 			break;
 		case SQL_TIMESTAMP:
 		case SQL_TIMESTAMP+1:
 			a_date_time = g_malloc0 (sizeof (struct tm));
 			isc_decode_timestamp ((ISC_TIMESTAMP *) field_data, a_date_time);
 			a_date_time->tm_mon ++;
+			a_date_time->tm_year += 1900;
 			a_times.hour = a_date_time->tm_hour;
 			a_times.minute = a_date_time->tm_min;
 			a_times.second = a_date_time->tm_sec;
@@ -528,6 +497,7 @@ fb_gda_value_fill (GdaValue *gda_value,
 			a_date_time = g_malloc0 (sizeof (struct tm));
 			isc_decode_sql_date ((ISC_DATE *) field_data, a_date_time);
 			a_date_time->tm_mon++;
+			a_date_time->tm_year += 1900;
 			a_date.year = a_date_time->tm_year;
 			a_date.month = a_date_time->tm_mon;
 			a_date.day = a_date_time->tm_mday;
@@ -592,7 +562,7 @@ fb_gda_value_fill (GdaValue *gda_value,
 			gda_value_set_double (gda_value, *((gdouble *) field_data));
 			break;
 		default:
-			g_print (_("Unknown Firebird's field value !\n"));
+			g_print (_("Unknown Firebird's field value!\n"));
 
 			gda_value_set_null (gda_value);
 			break;
@@ -937,7 +907,7 @@ gda_firebird_recordset_new (GdaConnection *cnc,
 	if (fb_sql_prepare (fcnc, recset, ftr, sql)) {
 
 		/* ... and then execute it */
-		if (! fb_sql_execute (fcnc, recset, ftr, sql)) {
+		if (!fb_sql_execute (fcnc, recset, ftr, sql)) {
 			gda_firebird_connection_make_error (cnc, fb_sql_get_statement_type (fcnc, recset));
 
 			/* Free Firebirds sql allocated space */
